Clazz.declarePackage("J.api");
Clazz.declareInterface(J.api, "JmolModulationSet");
;//5.0.1-v4 Tue Sep 10 11:29:28 CDT 2024
